# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v2/project_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v2/project_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.datasphere.v2 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_project__pb2
from yandex.cloud.datasphere.v2 import resource_types_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_resource__types__pb2
from yandex.cloud.datasphere.v2 import restrictions_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_restrictions__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/datasphere/v2/project_service.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a(yandex/cloud/datasphere/v2/project.proto\x1a/yandex/cloud/datasphere/v2/resource_types.proto\x1a-yandex/cloud/datasphere/v2/restrictions.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\xd2\x03\n\x14\x43reateProjectRequest\x12\"\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x04name\x18\x02 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x89\x01\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.datasphere.v2.CreateProjectRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.datasphere.v2.Project.Settings\x12:\n\x06limits\x18\x06 \x01(\x0b\x32*.yandex.cloud.datasphere.v2.Project.Limits\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"+\n\x15\x43reateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xfb\x03\n\x14UpdateProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x39\n\x04name\x18\x03 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x89\x01\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.datasphere.v2.UpdateProjectRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x08settings\x18\x06 \x01(\x0b\x32,.yandex.cloud.datasphere.v2.Project.Settings\x12:\n\x06limits\x18\x07 \x01(\x0b\x32*.yandex.cloud.datasphere.v2.Project.Limits\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"6\n\x12OpenProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa9\x03\n\x13OpenProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12Q\n\x06status\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.datasphere.v2.OpenProjectMetadata.OpenProjectStatus\"\xaa\x02\n\x11OpenProjectStatus\x12#\n\x1fOPEN_PROJECT_STATUS_UNSPECIFIED\x10\x00\x12#\n\x1fOPEN_PROJECT_STATUS_CLOSING_IDE\x10\x01\x12)\n%OPEN_PROJECT_STATUS_UNZIPPING_PROJECT\x10\x02\x12%\n!OPEN_PROJECT_STATUS_ALLOCATING_VM\x10\x03\x12,\n(OPEN_PROJECT_STATUS_ALLOCATING_RESOURCES\x10\x04\x12$\n OPEN_PROJECT_STATUS_STARTING_IDE\x10\x05\x12\x1f\n\x1bOPEN_PROJECT_STATUS_UNKNOWN\x10\x07\"\x04\x08\x06\x10\x06\"A\n\x13OpenProjectResponse\x12\x13\n\x0bproject_url\x18\x01 \x01(\t\x12\x15\n\rsession_token\x18\x02 \x01(\t\"5\n\x11GetProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa2\x01\n\x13ListProjectsRequest\x12\x1a\n\x0c\x63ommunity_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1c\n\x14project_name_pattern\x18\x04 \x01(\t\x12\x13\n\x0bowned_by_id\x18\x05 \x01(\t\"f\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.yandex.cloud.datasphere.v2.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x15GetUnitBalanceRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"K\n\x16GetUnitBalanceResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"l\n\x15SetUnitBalanceRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x31\n\x0cunit_balance\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\",\n\x16SetUnitBalanceMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x93\x02\n\x17ProjectExecutionRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1e\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\x0b\x18\x01\x8a\xc8\x31\x05<=200H\x00\x12\x30\n\x0finput_variables\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1d\n\x15output_variable_names\x18\x05 \x03(\t\x12\x0c\n\x04spec\x18\x06 \x01(\t\x12%\n\x12spark_connector_id\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=200B\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"~\n\x18ProjectExecutionMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"m\n\x18ProjectExecutionResponse\x12\x45\n\x10\x65xecution_status\x18\x03 \x01(\x0e\x32+.yandex.cloud.datasphere.v2.ExecutionStatusJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"6\n SetProjectAccessBindingsMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"9\n#UpdateProjectAccessBindingsMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x9b\x01\n\x1b\x41\x64\x64ResourceToProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12?\n\rresource_type\x18\x02 \x01(\x0e\x32(.yandex.cloud.datasphere.v2.ResourceType\x12\x19\n\x0bresource_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa0\x01\n RemoveResourceFromProjectRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12?\n\rresource_type\x18\x02 \x01(\x0e\x32(.yandex.cloud.datasphere.v2.ResourceType\x12\x19\n\x0bresource_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"9\n\x1dGetProjectRestrictionsRequest\x12\x18\n\nproject_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"x\n\x1dSetProjectRestrictionsRequest\x12\x18\n\nproject_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x0crestrictions\x18\x02 \x03(\x0b\x32\'.yandex.cloud.datasphere.v2.Restriction\"V\n\x18ResizeProjectDiskRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10new_disk_size_gb\x18\x02 \x01(\x03\"c\n\x19ResizeProjectDiskMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x18\n\x10old_disk_size_gb\x18\x02 \x01(\x03\x12\x18\n\x10new_disk_size_gb\x18\x03 \x01(\x03\"\x87\x02\n\x08\x44iskInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x02 \x01(\x01\x12\x14\n\x0c\x64isk_used_gb\x18\x03 \x01(\x01\x12M\n\x0e\x64\x65tailed_usage\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.datasphere.v2.DiskInfo.DetailedDiskInfo\x1al\n\x10\x44\x65tailedDiskInfo\x12\x14\n\x0cuser_data_gb\x18\x01 \x01(\x01\x12\x13\n\x0bpackages_gb\x18\x02 \x01(\x01\x12\x16\n\x0esystem_data_gb\x18\x03 \x01(\x01\x12\x15\n\rfree_space_gb\x18\x04 \x01(\x01*S\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x32\xc7\x1a\n\x0eProjectService\x12\xa5\x01\n\x06\x43reate\x12\x30.yandex.cloud.datasphere.v2.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02\x1c\"\x17/datasphere/v2/projects:\x01*\x12\xb2\x01\n\x06Update\x12\x30.yandex.cloud.datasphere.v2.UpdateProjectRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x15UpdateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02)2$/datasphere/v2/projects/{project_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.datasphere.v2.DeleteProjectRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*.\n\x15\x44\x65leteProjectMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/datasphere/v2/projects/{project_id}\x12\xbd\x01\n\x04Open\x12..yandex.cloud.datasphere.v2.OpenProjectRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2**\n\x13OpenProjectMetadata\x12\x13OpenProjectResponse\x82\xd3\xe4\x93\x02.\")/datasphere/v2/projects/{project_id}:open:\x01*\x12\x87\x01\n\x03Get\x12-.yandex.cloud.datasphere.v2.GetProjectRequest\x1a#.yandex.cloud.datasphere.v2.Project\",\x82\xd3\xe4\x93\x02&\x12$/datasphere/v2/projects/{project_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.datasphere.v2.ListProjectsRequest\x1a\x30.yandex.cloud.datasphere.v2.ListProjectsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/datasphere/v2/projects\x12\xb1\x01\n\x0eGetUnitBalance\x12\x31.yandex.cloud.datasphere.v2.GetUnitBalanceRequest\x1a\x32.yandex.cloud.datasphere.v2.GetUnitBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/datasphere/v2/projects/{project_id}:unitBalance\x12\xd6\x01\n\x0eSetUnitBalance\x12\x31.yandex.cloud.datasphere.v2.SetUnitBalanceRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*/\n\x16SetUnitBalanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35\"0/datasphere/v2/projects/{project_id}:unitBalance:\x01*\x12\xd2\x01\n\x07\x45xecute\x12\x33.yandex.cloud.datasphere.v2.ProjectExecutionRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*4\n\x18ProjectExecutionMetadata\x12\x18ProjectExecutionResponse\x82\xd3\xe4\x93\x02\x31\",/datasphere/v2/projects/{project_id}:execute:\x01*\x12\xb3\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/datasphere/v2/projects/{resource_id}:accessBindings\x12\xe6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*9\n SetProjectAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/datasphere/v2/projects/{resource_id}:setAccessBindings:\x01*\x12\xf3\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*<\n#UpdateProjectAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?2:/datasphere/v2/projects/{resource_id}:updateAccessBindings:\x01*\x12\xc2\x01\n\x0b\x41\x64\x64Resource\x12\x37.yandex.cloud.datasphere.v2.AddResourceToProjectRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36\"1/datasphere/v2/projects/{resource_id}:addResource:\x01*\x12\xcd\x01\n\x0eRemoveResource\x12<.yandex.cloud.datasphere.v2.RemoveResourceFromProjectRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/datasphere/v2/projects/{resource_id}:removeResource:\x01*\x12\x90\x01\n\nResizeDisk\x12\x34.yandex.cloud.datasphere.v2.ResizeProjectDiskRequest\x1a!.yandex.cloud.operation.Operation\")\xb2\xd2*%\n\x19ResizeProjectDiskMetadata\x12\x08\x44iskInfo\x12\x98\x01\n\x13GetRestrictionsMeta\x12\x16.google.protobuf.Empty\x1a\x37.yandex.cloud.datasphere.v2.GetRestrictionsMetaResponse\"0\x82\xd3\xe4\x93\x02*\x12(/datasphere/v2/projects/restrictionsMeta\x12\xb9\x01\n\x0fGetRestrictions\x12\x39.yandex.cloud.datasphere.v2.GetProjectRestrictionsRequest\x1a\x30.yandex.cloud.datasphere.v2.RestrictionsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/datasphere/v2/projects/{project_id}:restrictions\x12\xca\x01\n\x0fSetRestrictions\x12\x39.yandex.cloud.datasphere.v2.SetProjectRestrictionsRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x16\x12\x14RestrictionsResponse\x82\xd3\xe4\x93\x02\x39\"4/datasphere/v2/projects/{project_id}:setRestrictions:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.project_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['community_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['community_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['community_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['community_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._serialized_options = b'\030\001\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['spark_connector_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['spark_connector_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_ADDRESOURCETOPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDRESOURCETOPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDRESOURCETOPROJECTREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ADDRESOURCETOPROJECTREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_GETPROJECTRESTRICTIONSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTRESTRICTIONSREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001'
  _globals['_SETPROJECTRESTRICTIONSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETPROJECTRESTRICTIONSREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001'
  _globals['_RESIZEPROJECTDISKREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_RESIZEPROJECTDISKREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateProjectMetadata\022\007Project\202\323\344\223\002\034\"\027/datasphere/v2/projects:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateProjectMetadata\022\007Project\202\323\344\223\002)2$/datasphere/v2/projects/{project_id}:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteProjectMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/datasphere/v2/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._serialized_options = b'\262\322**\n\023OpenProjectMetadata\022\023OpenProjectResponse\202\323\344\223\002.\")/datasphere/v2/projects/{project_id}:open:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/datasphere/v2/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/datasphere/v2/projects'
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._serialized_options = b'\202\323\344\223\0022\0220/datasphere/v2/projects/{project_id}:unitBalance'
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._serialized_options = b'\262\322*/\n\026SetUnitBalanceMetadata\022\025google.protobuf.Empty\202\323\344\223\0025\"0/datasphere/v2/projects/{project_id}:unitBalance:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._serialized_options = b'\262\322*4\n\030ProjectExecutionMetadata\022\030ProjectExecutionResponse\202\323\344\223\0021\",/datasphere/v2/projects/{project_id}:execute:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0026\0224/datasphere/v2/projects/{resource_id}:accessBindings'
  _globals['_PROJECTSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n SetProjectAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002<\"7/datasphere/v2/projects/{resource_id}:setAccessBindings:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#UpdateProjectAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?2:/datasphere/v2/projects/{resource_id}:updateAccessBindings:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['AddResource']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['AddResource']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\0026\"1/datasphere/v2/projects/{resource_id}:addResource:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['RemoveResource']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['RemoveResource']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\0029\"4/datasphere/v2/projects/{resource_id}:removeResource:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['ResizeDisk']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['ResizeDisk']._serialized_options = b'\262\322*%\n\031ResizeProjectDiskMetadata\022\010DiskInfo'
  _globals['_PROJECTSERVICE'].methods_by_name['GetRestrictionsMeta']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['GetRestrictionsMeta']._serialized_options = b'\202\323\344\223\002*\022(/datasphere/v2/projects/restrictionsMeta'
  _globals['_PROJECTSERVICE'].methods_by_name['GetRestrictions']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['GetRestrictions']._serialized_options = b'\202\323\344\223\0023\0221/datasphere/v2/projects/{project_id}:restrictions'
  _globals['_PROJECTSERVICE'].methods_by_name['SetRestrictions']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['SetRestrictions']._serialized_options = b'\262\322*\026\022\024RestrictionsResponse\202\323\344\223\0029\"4/datasphere/v2/projects/{project_id}:setRestrictions:\001*'
  _globals['_EXECUTIONSTATUS']._serialized_start=4440
  _globals['_EXECUTIONSTATUS']._serialized_end=4523
  _globals['_CREATEPROJECTREQUEST']._serialized_start=513
  _globals['_CREATEPROJECTREQUEST']._serialized_end=979
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_start=928
  _globals['_CREATEPROJECTREQUEST_LABELSENTRY']._serialized_end=973
  _globals['_CREATEPROJECTMETADATA']._serialized_start=981
  _globals['_CREATEPROJECTMETADATA']._serialized_end=1024
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=1027
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1534
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_start=928
  _globals['_UPDATEPROJECTREQUEST_LABELSENTRY']._serialized_end=973
  _globals['_UPDATEPROJECTMETADATA']._serialized_start=1536
  _globals['_UPDATEPROJECTMETADATA']._serialized_end=1579
  _globals['_DELETEPROJECTREQUEST']._serialized_start=1581
  _globals['_DELETEPROJECTREQUEST']._serialized_end=1637
  _globals['_DELETEPROJECTMETADATA']._serialized_start=1639
  _globals['_DELETEPROJECTMETADATA']._serialized_end=1682
  _globals['_OPENPROJECTREQUEST']._serialized_start=1684
  _globals['_OPENPROJECTREQUEST']._serialized_end=1738
  _globals['_OPENPROJECTMETADATA']._serialized_start=1741
  _globals['_OPENPROJECTMETADATA']._serialized_end=2166
  _globals['_OPENPROJECTMETADATA_OPENPROJECTSTATUS']._serialized_start=1868
  _globals['_OPENPROJECTMETADATA_OPENPROJECTSTATUS']._serialized_end=2166
  _globals['_OPENPROJECTRESPONSE']._serialized_start=2168
  _globals['_OPENPROJECTRESPONSE']._serialized_end=2233
  _globals['_GETPROJECTREQUEST']._serialized_start=2235
  _globals['_GETPROJECTREQUEST']._serialized_end=2288
  _globals['_LISTPROJECTSREQUEST']._serialized_start=2291
  _globals['_LISTPROJECTSREQUEST']._serialized_end=2453
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=2455
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=2557
  _globals['_GETUNITBALANCEREQUEST']._serialized_start=2559
  _globals['_GETUNITBALANCEREQUEST']._serialized_end=2616
  _globals['_GETUNITBALANCERESPONSE']._serialized_start=2618
  _globals['_GETUNITBALANCERESPONSE']._serialized_end=2693
  _globals['_SETUNITBALANCEREQUEST']._serialized_start=2695
  _globals['_SETUNITBALANCEREQUEST']._serialized_end=2803
  _globals['_SETUNITBALANCEMETADATA']._serialized_start=2805
  _globals['_SETUNITBALANCEMETADATA']._serialized_end=2849
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_start=2852
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_end=3127
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_start=3129
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_end=3255
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_start=3257
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_end=3366
  _globals['_SETPROJECTACCESSBINDINGSMETADATA']._serialized_start=3368
  _globals['_SETPROJECTACCESSBINDINGSMETADATA']._serialized_end=3422
  _globals['_UPDATEPROJECTACCESSBINDINGSMETADATA']._serialized_start=3424
  _globals['_UPDATEPROJECTACCESSBINDINGSMETADATA']._serialized_end=3481
  _globals['_ADDRESOURCETOPROJECTREQUEST']._serialized_start=3484
  _globals['_ADDRESOURCETOPROJECTREQUEST']._serialized_end=3639
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST']._serialized_start=3642
  _globals['_REMOVERESOURCEFROMPROJECTREQUEST']._serialized_end=3802
  _globals['_GETPROJECTRESTRICTIONSREQUEST']._serialized_start=3804
  _globals['_GETPROJECTRESTRICTIONSREQUEST']._serialized_end=3861
  _globals['_SETPROJECTRESTRICTIONSREQUEST']._serialized_start=3863
  _globals['_SETPROJECTRESTRICTIONSREQUEST']._serialized_end=3983
  _globals['_RESIZEPROJECTDISKREQUEST']._serialized_start=3985
  _globals['_RESIZEPROJECTDISKREQUEST']._serialized_end=4071
  _globals['_RESIZEPROJECTDISKMETADATA']._serialized_start=4073
  _globals['_RESIZEPROJECTDISKMETADATA']._serialized_end=4172
  _globals['_DISKINFO']._serialized_start=4175
  _globals['_DISKINFO']._serialized_end=4438
  _globals['_DISKINFO_DETAILEDDISKINFO']._serialized_start=4330
  _globals['_DISKINFO_DETAILEDDISKINFO']._serialized_end=4438
  _globals['_PROJECTSERVICE']._serialized_start=4526
  _globals['_PROJECTSERVICE']._serialized_end=7925
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/access_control.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/access_control.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/trino/v1/access_control.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\xb2\x04\n\x13\x41\x63\x63\x65ssControlConfig\x12:\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32(.yandex.cloud.trino.v1.CatalogAccessRule\x12\x38\n\x07schemas\x18\x02 \x03(\x0b\x32\'.yandex.cloud.trino.v1.SchemaAccessRule\x12\x36\n\x06tables\x18\x03 \x03(\x0b\x32&.yandex.cloud.trino.v1.TableAccessRule\x12<\n\tfunctions\x18\x04 \x03(\x0b\x32).yandex.cloud.trino.v1.FunctionAccessRule\x12>\n\nprocedures\x18\x05 \x03(\x0b\x32*.yandex.cloud.trino.v1.ProcedureAccessRule\x12\x37\n\x07queries\x18\x06 \x03(\x0b\x32&.yandex.cloud.trino.v1.QueryAccessRule\x12Y\n\x19system_session_properties\x18\x07 \x03(\x0b\x32\x36.yandex.cloud.trino.v1.SystemSessionPropertyAccessRule\x12[\n\x1a\x63\x61talog_session_properties\x18\x08 \x03(\x0b\x32\x37.yandex.cloud.trino.v1.CatalogSessionPropertyAccessRule\"\xda\x02\n\x18\x43\x61talogAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.yandex.cloud.trino.v1.CatalogAccessRuleMatcher.CatalogIdsH\x00\x12M\n\x05names\x18\x05 \x01(\x0b\x32<.yandex.cloud.trino.v1.CatalogAccessRuleMatcher.CatalogNamesH\x00\x1a\x30\n\nCatalogIds\x12\"\n\x03\x61ny\x18\x01 \x03(\tB\x15\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x1a\x32\n\x0c\x43\x61talogNames\x12\"\n\x03\x61ny\x18\x01 \x03(\tB\x15\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xe2\x01\n\x17SchemaAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12K\n\x05names\x18\x03 \x01(\x0b\x32:.yandex.cloud.trino.v1.SchemaAccessRuleMatcher.SchemaNamesH\x00\x1a@\n\x0bSchemaNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xde\x01\n\x16TableAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12I\n\x05names\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.trino.v1.TableAccessRuleMatcher.TableNamesH\x00\x1a?\n\nTableNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xea\x01\n\x19\x46unctionAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12O\n\x05names\x18\x03 \x01(\x0b\x32>.yandex.cloud.trino.v1.FunctionAccessRuleMatcher.FunctionNamesH\x00\x1a\x42\n\rFunctionNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xee\x01\n\x1aProcedureAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12Q\n\x05names\x18\x03 \x01(\x0b\x32@.yandex.cloud.trino.v1.ProcedureAccessRuleMatcher.ProcedureNamesH\x00\x1a\x43\n\x0eProcedureNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xe6\x01\n\x19PropertyAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12O\n\x05names\x18\x03 \x01(\x0b\x32>.yandex.cloud.trino.v1.PropertyAccessRuleMatcher.PropertyNamesH\x00\x1a>\n\rPropertyNames\x12-\n\x03\x61ny\x18\x01 \x03(\tB \xf2\xc7\x31\x07[a-z_]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\x81\x03\n\x11\x43\x61talogAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12M\n\npermission\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.trino.v1.CatalogAccessRule.PermissionB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"J\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x12\r\n\tREAD_ONLY\x10\x03J\x04\x08\x02\x10\x03\"\x9a\x03\n\x10SchemaAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x42\n\x05owner\x18\x06 \x01(\x0e\x32-.yandex.cloud.trino.v1.SchemaAccessRule.OwnerB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05Owner\x12\x15\n\x11OWNER_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\"\xe5\x06\n\x0fTableAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12<\n\x05table\x18\x06 \x01(\x0b\x32-.yandex.cloud.trino.v1.TableAccessRuleMatcher\x12J\n\nprivileges\x18\x07 \x03(\x0e\x32\x30.yandex.cloud.trino.v1.TableAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12>\n\x07\x63olumns\x18\x08 \x03(\x0b\x32-.yandex.cloud.trino.v1.TableAccessRule.Column\x12\x19\n\x06\x66ilter\x18\t \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x1e\n\x0b\x64\x65scription\x18\x0b \x01(\tB\t\x8a\xc8\x31\x05<=128\x1a\xda\x01\n\x06\x43olumn\x12)\n\x04name\x18\x01 \x01(\tB\x1b\xe8\xc7\x31\x01\xf2\xc7\x31\x0b[a-z0-9_-]+\x8a\xc8\x31\x04<=63\x12N\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.trino.v1.TableAccessRule.Column.AccessModeB\x04\xe8\xc7\x31\x01\x12\x17\n\x04mask\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=128\"<\n\nAccessMode\x12\x1b\n\x17\x41\x43\x43\x45SS_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x41LL\x10\x02\"w\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\n\n\x06INSERT\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04\x12\r\n\tOWNERSHIP\x10\x05\x12\x10\n\x0cGRANT_SELECT\x10\x06J\x04\x08\x02\x10\x03J\x04\x08\n\x10\x0b\"\x91\x04\n\x12\x46unctionAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x42\n\x08\x66unction\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.FunctionAccessRuleMatcher\x12M\n\nprivileges\x18\x07 \x03(\x0e\x32\x33.yandex.cloud.trino.v1.FunctionAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=128\"U\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XECUTE\x10\x01\x12\x11\n\rGRANT_EXECUTE\x10\x02\x12\r\n\tOWNERSHIP\x10\x03J\x04\x08\x02\x10\x03\"\xf9\x03\n\x13ProcedureAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x44\n\tprocedure\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.trino.v1.ProcedureAccessRuleMatcher\x12N\n\nprivileges\x18\x07 \x03(\x0e\x32\x34.yandex.cloud.trino.v1.ProcedureAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=128\"9\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XECUTE\x10\x01\"\x04\x08\x02\x10\x02J\x04\x08\x02\x10\x03\"\xf3\x02\n\x0fQueryAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12:\n\x0cquery_owners\x18\x04 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12J\n\nprivileges\x18\x05 \x03(\x0e\x32\x30.yandex.cloud.trino.v1.QueryAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"G\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0b\n\x07\x45XECUTE\x10\x02\x12\x08\n\x04KILL\x10\x03J\x04\x08\x02\x10\x03\"\xfa\x02\n\x1fSystemSessionPropertyAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x42\n\x08property\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.PropertyAccessRuleMatcher\x12Q\n\x05\x61llow\x18\x05 \x01(\x0e\x32<.yandex.cloud.trino.v1.SystemSessionPropertyAccessRule.AllowB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05\x41llow\x12\x15\n\x11\x41LLOW_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\"\xbe\x03\n CatalogSessionPropertyAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12\x42\n\x08property\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.PropertyAccessRuleMatcher\x12R\n\x05\x61llow\x18\x06 \x01(\x0e\x32=.yandex.cloud.trino.v1.CatalogSessionPropertyAccessRule.AllowB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05\x41llow\x12\x15\n\x11\x41LLOW_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.access_control_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS'].fields_by_name['any']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS'].fields_by_name['any']._serialized_options = b'\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES'].fields_by_name['any']._serialized_options = b'\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_CATALOGACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES'].fields_by_name['any']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_SCHEMAACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES'].fields_by_name['any']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_TABLEACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_FUNCTIONACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES'].fields_by_name['any']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_PROCEDUREACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES'].fields_by_name['any']._serialized_options = b'\362\3071\007[a-z_]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROPERTYACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_PROPERTYACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['permission']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['owner']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['owner']._serialized_options = b'\350\3071\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['name']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\013[a-z0-9_-]+\212\3101\004<=63'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['access']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['access']._serialized_options = b'\350\3071\001'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['mask']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['mask']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['filter']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['filter']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_QUERYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['query_owners']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['query_owners']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._serialized_options = b'\350\3071\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_ACCESSCONTROLCONFIG']._serialized_start=101
  _globals['_ACCESSCONTROLCONFIG']._serialized_end=663
  _globals['_CATALOGACCESSRULEMATCHER']._serialized_start=666
  _globals['_CATALOGACCESSRULEMATCHER']._serialized_end=1012
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS']._serialized_start=882
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS']._serialized_end=930
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES']._serialized_start=932
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES']._serialized_end=982
  _globals['_SCHEMAACCESSRULEMATCHER']._serialized_start=1015
  _globals['_SCHEMAACCESSRULEMATCHER']._serialized_end=1241
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES']._serialized_start=1153
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES']._serialized_end=1217
  _globals['_TABLEACCESSRULEMATCHER']._serialized_start=1244
  _globals['_TABLEACCESSRULEMATCHER']._serialized_end=1466
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES']._serialized_start=1379
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES']._serialized_end=1442
  _globals['_FUNCTIONACCESSRULEMATCHER']._serialized_start=1469
  _globals['_FUNCTIONACCESSRULEMATCHER']._serialized_end=1703
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES']._serialized_start=1613
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES']._serialized_end=1679
  _globals['_PROCEDUREACCESSRULEMATCHER']._serialized_start=1706
  _globals['_PROCEDUREACCESSRULEMATCHER']._serialized_end=1944
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES']._serialized_start=1853
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES']._serialized_end=1920
  _globals['_PROPERTYACCESSRULEMATCHER']._serialized_start=1947
  _globals['_PROPERTYACCESSRULEMATCHER']._serialized_end=2177
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES']._serialized_start=2091
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES']._serialized_end=2153
  _globals['_CATALOGACCESSRULE']._serialized_start=2180
  _globals['_CATALOGACCESSRULE']._serialized_end=2565
  _globals['_CATALOGACCESSRULE_PERMISSION']._serialized_start=2485
  _globals['_CATALOGACCESSRULE_PERMISSION']._serialized_end=2559
  _globals['_SCHEMAACCESSRULE']._serialized_start=2568
  _globals['_SCHEMAACCESSRULE']._serialized_end=2978
  _globals['_SCHEMAACCESSRULE_OWNER']._serialized_start=2925
  _globals['_SCHEMAACCESSRULE_OWNER']._serialized_end=2972
  _globals['_TABLEACCESSRULE']._serialized_start=2981
  _globals['_TABLEACCESSRULE']._serialized_end=3850
  _globals['_TABLEACCESSRULE_COLUMN']._serialized_start=3499
  _globals['_TABLEACCESSRULE_COLUMN']._serialized_end=3717
  _globals['_TABLEACCESSRULE_COLUMN_ACCESSMODE']._serialized_start=3657
  _globals['_TABLEACCESSRULE_COLUMN_ACCESSMODE']._serialized_end=3717
  _globals['_TABLEACCESSRULE_PRIVILEGE']._serialized_start=3719
  _globals['_TABLEACCESSRULE_PRIVILEGE']._serialized_end=3838
  _globals['_FUNCTIONACCESSRULE']._serialized_start=3853
  _globals['_FUNCTIONACCESSRULE']._serialized_end=4382
  _globals['_FUNCTIONACCESSRULE_PRIVILEGE']._serialized_start=4291
  _globals['_FUNCTIONACCESSRULE_PRIVILEGE']._serialized_end=4376
  _globals['_PROCEDUREACCESSRULE']._serialized_start=4385
  _globals['_PROCEDUREACCESSRULE']._serialized_end=4890
  _globals['_PROCEDUREACCESSRULE_PRIVILEGE']._serialized_start=4827
  _globals['_PROCEDUREACCESSRULE_PRIVILEGE']._serialized_end=4884
  _globals['_QUERYACCESSRULE']._serialized_start=4893
  _globals['_QUERYACCESSRULE']._serialized_end=5264
  _globals['_QUERYACCESSRULE_PRIVILEGE']._serialized_start=5187
  _globals['_QUERYACCESSRULE_PRIVILEGE']._serialized_end=5258
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE']._serialized_start=5267
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE']._serialized_end=5645
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_start=5592
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_end=5639
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE']._serialized_start=5648
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE']._serialized_end=6094
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_start=5592
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_end=5639
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.stt.v2 import stt_service_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/stt/v2/stt_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SttServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LongRunningRecognize = channel.unary_unary(
                '/yandex.cloud.ai.stt.v2.SttService/LongRunningRecognize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.LongRunningRecognitionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.StreamingRecognize = channel.stream_stream(
                '/yandex.cloud.ai.stt.v2.SttService/StreamingRecognize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionResponse.FromString,
                _registered_method=True)


class SttServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LongRunningRecognize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamingRecognize(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SttServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LongRunningRecognize': grpc.unary_unary_rpc_method_handler(
                    servicer.LongRunningRecognize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.LongRunningRecognitionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'StreamingRecognize': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamingRecognize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.stt.v2.SttService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.stt.v2.SttService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SttService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LongRunningRecognize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.stt.v2.SttService/LongRunningRecognize',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.LongRunningRecognitionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamingRecognize(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/yandex.cloud.ai.stt.v2.SttService/StreamingRecognize',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_stt_dot_v2_dot_stt__service__pb2.StreamingRecognitionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
